]> git.saurik.com Git - bison.git/commitdiff
* LR0.c (new_itemsets): Fix wording in comments: say item index rather
authorJoel E. Denny <jdenny@ces.clemson.edu>
Tue, 10 Jul 2007 02:57:31 +0000 (02:57 +0000)
committerJoel E. Denny <jdenny@ces.clemson.edu>
Tue, 10 Jul 2007 02:57:31 +0000 (02:57 +0000)
than item number.
* closure.c (closure): Likewise.
* state.h (reductions): Comment sorting of rules.
(state): Comment sorting of items.

ChangeLog
src/LR0.c
src/closure.c
src/state.h

index 9c2618947c081f1438f38598b1d9198e2c872053..8f331164f4a3201fcf5cdd6c61fc2445e411d139 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,11 @@
+2007-07-09  Joel E. Denny  <jdenny@ces.clemson.edu>
+
+       * LR0.c (new_itemsets): Fix wording in comments: say item index rather
+       than item number.
+       * closure.c (closure): Likewise.
+       * state.h (reductions): Comment sorting of rules.
+       (state): Comment sorting of items.
+
 2007-07-02  Joel E. Denny  <jdenny@ces.clemson.edu>
 
        Fix C++ test cases after recent Gnulib changes.  Discussed starting at
 2007-07-02  Joel E. Denny  <jdenny@ces.clemson.edu>
 
        Fix C++ test cases after recent Gnulib changes.  Discussed starting at
index 6e3a4460174b9e631a712dcec83598ec65bbfe6e..689bebcbebf33f81627c7aa3236da32dfec51deb 100644 (file)
--- a/src/LR0.c
+++ b/src/LR0.c
@@ -170,9 +170,9 @@ free_storage (void)
 | points to a vector of item numbers activated if that symbol is |
 | shifted, and kernel_size[symbol] is their numbers.             |
 |                                                                |
 | points to a vector of item numbers activated if that symbol is |
 | shifted, and kernel_size[symbol] is their numbers.             |
 |                                                                |
-| itemset is sorted on item number from ritem, which is sorted   |
-| on rule number.  Compute each kernel_base[symbol] with the     |
-| same sort.                                                     |
+| itemset is sorted on item index in ritem, which is sorted on   |
+| rule number.  Compute each kernel_base[symbol] with the same   |
+| sort.                                                          |
 `---------------------------------------------------------------*/
 
 static void
 `---------------------------------------------------------------*/
 
 static void
index 339adf5dbe216de8ffa1e80110830d5db07cb192..a6cc784a49c837d100c6fa9e053d001804bdb9db 100644 (file)
@@ -213,7 +213,7 @@ closure (item_number *core, size_t n)
     if (ISVAR (ritem[core[c]]))
       bitset_or (ruleset, ruleset, FDERIVES (ritem[core[c]]));
 
     if (ISVAR (ritem[core[c]]))
       bitset_or (ruleset, ruleset, FDERIVES (ritem[core[c]]));
 
/* core is sorted on item number from ritem, which is sorted on rule number.
      Compute itemset with the same sort.  */
   nitemset = 0;
   c = 0;
      Compute itemset with the same sort.  */
   nitemset = 0;
   c = 0;
index 2d67bb7c31b6b0e6fa19d9fc7927d48a9c5107bd..390ab8af2f6f7849784165b7aeb94c717b47030b 100644 (file)
@@ -185,6 +185,7 @@ typedef struct
 {
   int num;
   bitset *lookahead_tokens;
 {
   int num;
   bitset *lookahead_tokens;
+  /* Sorted ascendingly on rule number.  */
   rule *rules[1];
 } reductions;
 
   rule *rules[1];
 } reductions;
 
@@ -210,8 +211,8 @@ struct state
      a human readable description of the resolution.  */
   const char *solved_conflicts;
 
      a human readable description of the resolution.  */
   const char *solved_conflicts;
 
-  /* Its items.  Must be last, since ITEMS can be arbitrarily large.
-     */
+  /* Its items.  Must be last, since ITEMS can be arbitrarily large.  Sorted
+     ascendingly on item index in RITEM, which is sorted on rule number.  */
   size_t nitems;
   item_number items[1];
 };
@@ -213,7 +213,7 @@ closure (item_number *core, size_t n)
       bitset_or (ruleset, ruleset, FDERIVES (ritem[core[c]]));
 
-  /* core is sorted on item number from ritem, which is sorted on rule number.
+  /* core is sorted on item index in ritem, which is sorted on rule number.
      Compute itemset with the same sort.  */
   nitemset = 0;
   size_t nitems;
   item_number items[1];
 };